import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleApiGatewayApiConfigAConfig extends cdktf.TerraformMetaArguments {
    /**
    * The API to attach the config to.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_api_gateway_api_config#api GoogleApiGatewayApiConfigA#api}
    */
    readonly api: string;
    /**
    * Identifier to assign to the API Config. Must be unique within scope of the parent resource(api).
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_api_gateway_api_config#api_config_id GoogleApiGatewayApiConfigA#api_config_id}
    */
    readonly apiConfigId?: string;
    /**
    * Creates a unique name beginning with the specified prefix. If this and api_config_id are unspecified, a random value is chosen for the name.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_api_gateway_api_config#api_config_id_prefix GoogleApiGatewayApiConfigA#api_config_id_prefix}
    */
    readonly apiConfigIdPrefix?: string;
    /**
    * A user-visible name for the API.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_api_gateway_api_config#display_name GoogleApiGatewayApiConfigA#display_name}
    */
    readonly displayName?: string;
    /**
    * Resource labels to represent user-provided metadata.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_api_gateway_api_config#labels GoogleApiGatewayApiConfigA#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_api_gateway_api_config#project GoogleApiGatewayApiConfigA#project}
    */
    readonly project?: string;
    /**
    * gateway_config block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_api_gateway_api_config#gateway_config GoogleApiGatewayApiConfigA#gateway_config}
    */
    readonly gatewayConfig?: GoogleApiGatewayApiConfigGatewayConfig;
    /**
    * openapi_documents block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_api_gateway_api_config#openapi_documents GoogleApiGatewayApiConfigA#openapi_documents}
    */
    readonly openapiDocuments: GoogleApiGatewayApiConfigOpenapiDocuments[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_api_gateway_api_config#timeouts GoogleApiGatewayApiConfigA#timeouts}
    */
    readonly timeouts?: GoogleApiGatewayApiConfigTimeouts;
}
export interface GoogleApiGatewayApiConfigGatewayConfigBackendConfig {
    /**
    * Google Cloud IAM service account used to sign OIDC tokens for backends that have authentication configured
  (https://cloud.google.com/service-infrastructure/docs/service-management/reference/rest/v1/services.configs#backend).
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_api_gateway_api_config#google_service_account GoogleApiGatewayApiConfigA#google_service_account}
    */
    readonly googleServiceAccount: string;
}
export declare function googleApiGatewayApiConfigGatewayConfigBackendConfigToTerraform(struct?: GoogleApiGatewayApiConfigGatewayConfigBackendConfigOutputReference | GoogleApiGatewayApiConfigGatewayConfigBackendConfig): any;
export declare class GoogleApiGatewayApiConfigGatewayConfigBackendConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleApiGatewayApiConfigGatewayConfigBackendConfig | undefined;
    set internalValue(value: GoogleApiGatewayApiConfigGatewayConfigBackendConfig | undefined);
    private _googleServiceAccount?;
    get googleServiceAccount(): string;
    set googleServiceAccount(value: string);
    get googleServiceAccountInput(): string | undefined;
}
export interface GoogleApiGatewayApiConfigGatewayConfig {
    /**
    * backend_config block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_api_gateway_api_config#backend_config GoogleApiGatewayApiConfigA#backend_config}
    */
    readonly backendConfig: GoogleApiGatewayApiConfigGatewayConfigBackendConfig;
}
export declare function googleApiGatewayApiConfigGatewayConfigToTerraform(struct?: GoogleApiGatewayApiConfigGatewayConfigOutputReference | GoogleApiGatewayApiConfigGatewayConfig): any;
export declare class GoogleApiGatewayApiConfigGatewayConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleApiGatewayApiConfigGatewayConfig | undefined;
    set internalValue(value: GoogleApiGatewayApiConfigGatewayConfig | undefined);
    private _backendConfig;
    get backendConfig(): GoogleApiGatewayApiConfigGatewayConfigBackendConfigOutputReference;
    putBackendConfig(value: GoogleApiGatewayApiConfigGatewayConfigBackendConfig): void;
    get backendConfigInput(): GoogleApiGatewayApiConfigGatewayConfigBackendConfig | undefined;
}
export interface GoogleApiGatewayApiConfigOpenapiDocumentsDocument {
    /**
    * Base64 encoded content of the file.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_api_gateway_api_config#contents GoogleApiGatewayApiConfigA#contents}
    */
    readonly contents: string;
    /**
    * The file path (full or relative path). This is typically the path of the file when it is uploaded.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_api_gateway_api_config#path GoogleApiGatewayApiConfigA#path}
    */
    readonly path: string;
}
export declare function googleApiGatewayApiConfigOpenapiDocumentsDocumentToTerraform(struct?: GoogleApiGatewayApiConfigOpenapiDocumentsDocumentOutputReference | GoogleApiGatewayApiConfigOpenapiDocumentsDocument): any;
export declare class GoogleApiGatewayApiConfigOpenapiDocumentsDocumentOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleApiGatewayApiConfigOpenapiDocumentsDocument | undefined;
    set internalValue(value: GoogleApiGatewayApiConfigOpenapiDocumentsDocument | undefined);
    private _contents?;
    get contents(): string;
    set contents(value: string);
    get contentsInput(): string | undefined;
    private _path?;
    get path(): string;
    set path(value: string);
    get pathInput(): string | undefined;
}
export interface GoogleApiGatewayApiConfigOpenapiDocuments {
    /**
    * document block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_api_gateway_api_config#document GoogleApiGatewayApiConfigA#document}
    */
    readonly document: GoogleApiGatewayApiConfigOpenapiDocumentsDocument;
}
export declare function googleApiGatewayApiConfigOpenapiDocumentsToTerraform(struct?: GoogleApiGatewayApiConfigOpenapiDocuments | cdktf.IResolvable): any;
export interface GoogleApiGatewayApiConfigTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_api_gateway_api_config#create GoogleApiGatewayApiConfigA#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_api_gateway_api_config#delete GoogleApiGatewayApiConfigA#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_api_gateway_api_config#update GoogleApiGatewayApiConfigA#update}
    */
    readonly update?: string;
}
export declare function googleApiGatewayApiConfigTimeoutsToTerraform(struct?: GoogleApiGatewayApiConfigTimeoutsOutputReference | GoogleApiGatewayApiConfigTimeouts | cdktf.IResolvable): any;
export declare class GoogleApiGatewayApiConfigTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleApiGatewayApiConfigTimeouts | undefined;
    set internalValue(value: GoogleApiGatewayApiConfigTimeouts | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_api_gateway_api_config google_api_gateway_api_config}
*/
export declare class GoogleApiGatewayApiConfigA extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_api_gateway_api_config";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_api_gateway_api_config google_api_gateway_api_config} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleApiGatewayApiConfigAConfig
    */
    constructor(scope: Construct, id: string, config: GoogleApiGatewayApiConfigAConfig);
    private _api?;
    get api(): string;
    set api(value: string);
    get apiInput(): string | undefined;
    private _apiConfigId?;
    get apiConfigId(): string;
    set apiConfigId(value: string);
    resetApiConfigId(): void;
    get apiConfigIdInput(): string | undefined;
    private _apiConfigIdPrefix?;
    get apiConfigIdPrefix(): string;
    set apiConfigIdPrefix(value: string);
    resetApiConfigIdPrefix(): void;
    get apiConfigIdPrefixInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    get id(): string;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get serviceConfigId(): string;
    private _gatewayConfig;
    get gatewayConfig(): GoogleApiGatewayApiConfigGatewayConfigOutputReference;
    putGatewayConfig(value: GoogleApiGatewayApiConfigGatewayConfig): void;
    resetGatewayConfig(): void;
    get gatewayConfigInput(): GoogleApiGatewayApiConfigGatewayConfig | undefined;
    private _openapiDocuments?;
    get openapiDocuments(): GoogleApiGatewayApiConfigOpenapiDocuments[] | cdktf.IResolvable;
    set openapiDocuments(value: GoogleApiGatewayApiConfigOpenapiDocuments[] | cdktf.IResolvable);
    get openapiDocumentsInput(): cdktf.IResolvable | GoogleApiGatewayApiConfigOpenapiDocuments[] | undefined;
    private _timeouts;
    get timeouts(): GoogleApiGatewayApiConfigTimeoutsOutputReference;
    putTimeouts(value: GoogleApiGatewayApiConfigTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): GoogleApiGatewayApiConfigTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
//# sourceMappingURL=google-api-gateway-api-config.d.ts.map