import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleCloudIdentityGroupMembershipConfig extends cdktf.TerraformMetaArguments {
    /**
    * The name of the Group to create this membership in.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_identity_group_membership#group GoogleCloudIdentityGroupMembership#group}
    */
    readonly group: string;
    /**
    * member_key block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_identity_group_membership#member_key GoogleCloudIdentityGroupMembership#member_key}
    */
    readonly memberKey?: GoogleCloudIdentityGroupMembershipMemberKey;
    /**
    * preferred_member_key block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_identity_group_membership#preferred_member_key GoogleCloudIdentityGroupMembership#preferred_member_key}
    */
    readonly preferredMemberKey?: GoogleCloudIdentityGroupMembershipPreferredMemberKey;
    /**
    * roles block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_identity_group_membership#roles GoogleCloudIdentityGroupMembership#roles}
    */
    readonly roles: GoogleCloudIdentityGroupMembershipRoles[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_identity_group_membership#timeouts GoogleCloudIdentityGroupMembership#timeouts}
    */
    readonly timeouts?: GoogleCloudIdentityGroupMembershipTimeouts;
}
export interface GoogleCloudIdentityGroupMembershipMemberKey {
    /**
    * The ID of the entity.
  
  For Google-managed entities, the id must be the email address of an existing
  group or user.
  
  For external-identity-mapped entities, the id must be a string conforming
  to the Identity Source's requirements.
  
  Must be unique within a namespace.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_identity_group_membership#id GoogleCloudIdentityGroupMembership#id}
    */
    readonly id: string;
    /**
    * The namespace in which the entity exists.
  
  If not specified, the EntityKey represents a Google-managed entity
  such as a Google user or a Google Group.
  
  If specified, the EntityKey represents an external-identity-mapped group.
  The namespace must correspond to an identity source created in Admin Console
  and must be in the form of 'identitysources/{identity_source_id}'.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_identity_group_membership#namespace GoogleCloudIdentityGroupMembership#namespace}
    */
    readonly namespace?: string;
}
export declare function googleCloudIdentityGroupMembershipMemberKeyToTerraform(struct?: GoogleCloudIdentityGroupMembershipMemberKeyOutputReference | GoogleCloudIdentityGroupMembershipMemberKey): any;
export declare class GoogleCloudIdentityGroupMembershipMemberKeyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudIdentityGroupMembershipMemberKey | undefined;
    set internalValue(value: GoogleCloudIdentityGroupMembershipMemberKey | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
}
export interface GoogleCloudIdentityGroupMembershipPreferredMemberKey {
    /**
    * The ID of the entity.
  
  For Google-managed entities, the id must be the email address of an existing
  group or user.
  
  For external-identity-mapped entities, the id must be a string conforming
  to the Identity Source's requirements.
  
  Must be unique within a namespace.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_identity_group_membership#id GoogleCloudIdentityGroupMembership#id}
    */
    readonly id: string;
    /**
    * The namespace in which the entity exists.
  
  If not specified, the EntityKey represents a Google-managed entity
  such as a Google user or a Google Group.
  
  If specified, the EntityKey represents an external-identity-mapped group.
  The namespace must correspond to an identity source created in Admin Console
  and must be in the form of 'identitysources/{identity_source_id}'.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_identity_group_membership#namespace GoogleCloudIdentityGroupMembership#namespace}
    */
    readonly namespace?: string;
}
export declare function googleCloudIdentityGroupMembershipPreferredMemberKeyToTerraform(struct?: GoogleCloudIdentityGroupMembershipPreferredMemberKeyOutputReference | GoogleCloudIdentityGroupMembershipPreferredMemberKey): any;
export declare class GoogleCloudIdentityGroupMembershipPreferredMemberKeyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudIdentityGroupMembershipPreferredMemberKey | undefined;
    set internalValue(value: GoogleCloudIdentityGroupMembershipPreferredMemberKey | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
}
export interface GoogleCloudIdentityGroupMembershipRoles {
    /**
    * The name of the MembershipRole. Must be one of OWNER, MANAGER, MEMBER. Possible values: ["OWNER", "MANAGER", "MEMBER"]
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_identity_group_membership#name GoogleCloudIdentityGroupMembership#name}
    */
    readonly name: string;
}
export declare function googleCloudIdentityGroupMembershipRolesToTerraform(struct?: GoogleCloudIdentityGroupMembershipRoles | cdktf.IResolvable): any;
export interface GoogleCloudIdentityGroupMembershipTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_identity_group_membership#create GoogleCloudIdentityGroupMembership#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_identity_group_membership#delete GoogleCloudIdentityGroupMembership#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_identity_group_membership#update GoogleCloudIdentityGroupMembership#update}
    */
    readonly update?: string;
}
export declare function googleCloudIdentityGroupMembershipTimeoutsToTerraform(struct?: GoogleCloudIdentityGroupMembershipTimeoutsOutputReference | GoogleCloudIdentityGroupMembershipTimeouts | cdktf.IResolvable): any;
export declare class GoogleCloudIdentityGroupMembershipTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudIdentityGroupMembershipTimeouts | undefined;
    set internalValue(value: GoogleCloudIdentityGroupMembershipTimeouts | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_identity_group_membership google_cloud_identity_group_membership}
*/
export declare class GoogleCloudIdentityGroupMembership extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_cloud_identity_group_membership";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_cloud_identity_group_membership google_cloud_identity_group_membership} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleCloudIdentityGroupMembershipConfig
    */
    constructor(scope: Construct, id: string, config: GoogleCloudIdentityGroupMembershipConfig);
    get createTime(): string;
    private _group?;
    get group(): string;
    set group(value: string);
    get groupInput(): string | undefined;
    get id(): string;
    get name(): string;
    get type(): string;
    get updateTime(): string;
    private _memberKey;
    get memberKey(): GoogleCloudIdentityGroupMembershipMemberKeyOutputReference;
    putMemberKey(value: GoogleCloudIdentityGroupMembershipMemberKey): void;
    resetMemberKey(): void;
    get memberKeyInput(): GoogleCloudIdentityGroupMembershipMemberKey | undefined;
    private _preferredMemberKey;
    get preferredMemberKey(): GoogleCloudIdentityGroupMembershipPreferredMemberKeyOutputReference;
    putPreferredMemberKey(value: GoogleCloudIdentityGroupMembershipPreferredMemberKey): void;
    resetPreferredMemberKey(): void;
    get preferredMemberKeyInput(): GoogleCloudIdentityGroupMembershipPreferredMemberKey | undefined;
    private _roles?;
    get roles(): GoogleCloudIdentityGroupMembershipRoles[] | cdktf.IResolvable;
    set roles(value: GoogleCloudIdentityGroupMembershipRoles[] | cdktf.IResolvable);
    get rolesInput(): cdktf.IResolvable | GoogleCloudIdentityGroupMembershipRoles[] | undefined;
    private _timeouts;
    get timeouts(): GoogleCloudIdentityGroupMembershipTimeoutsOutputReference;
    putTimeouts(value: GoogleCloudIdentityGroupMembershipTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): GoogleCloudIdentityGroupMembershipTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
//# sourceMappingURL=google-cloud-identity-group-membership.d.ts.map