import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleDnsResponsePolicyRuleConfig extends cdktf.TerraformMetaArguments {
    /**
    * The DNS name (wildcard or exact) to apply this rule to. Must be unique within the Response Policy Rule.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy_rule#dns_name GoogleDnsResponsePolicyRule#dns_name}
    */
    readonly dnsName: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy_rule#project GoogleDnsResponsePolicyRule#project}
    */
    readonly project?: string;
    /**
    * Identifies the response policy addressed by this request.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy_rule#response_policy GoogleDnsResponsePolicyRule#response_policy}
    */
    readonly responsePolicy: string;
    /**
    * An identifier for this rule. Must be unique with the ResponsePolicy.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy_rule#rule_name GoogleDnsResponsePolicyRule#rule_name}
    */
    readonly ruleName: string;
    /**
    * local_data block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy_rule#local_data GoogleDnsResponsePolicyRule#local_data}
    */
    readonly localData?: GoogleDnsResponsePolicyRuleLocalData;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy_rule#timeouts GoogleDnsResponsePolicyRule#timeouts}
    */
    readonly timeouts?: GoogleDnsResponsePolicyRuleTimeouts;
}
export interface GoogleDnsResponsePolicyRuleLocalDataLocalDatas {
    /**
    * For example, www.example.com.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy_rule#name GoogleDnsResponsePolicyRule#name}
    */
    readonly name: string;
    /**
    * As defined in RFC 1035 (section 5) and RFC 1034 (section 3.6.1)
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy_rule#rrdatas GoogleDnsResponsePolicyRule#rrdatas}
    */
    readonly rrdatas?: string[];
    /**
    * Number of seconds that this ResourceRecordSet can be cached by
  resolvers.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy_rule#ttl GoogleDnsResponsePolicyRule#ttl}
    */
    readonly ttl?: number;
    /**
    * One of valid DNS resource types. Possible values: ["A", "AAAA", "CAA", "CNAME", "DNSKEY", "DS", "HTTPS", "IPSECVPNKEY", "MX", "NAPTR", "NS", "PTR", "SOA", "SPF", "SRV", "SSHFP", "SVCB", "TLSA", "TXT"]
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy_rule#type GoogleDnsResponsePolicyRule#type}
    */
    readonly type: string;
}
export declare function googleDnsResponsePolicyRuleLocalDataLocalDatasToTerraform(struct?: GoogleDnsResponsePolicyRuleLocalDataLocalDatas | cdktf.IResolvable): any;
export interface GoogleDnsResponsePolicyRuleLocalData {
    /**
    * local_datas block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy_rule#local_datas GoogleDnsResponsePolicyRule#local_datas}
    */
    readonly localDatas: GoogleDnsResponsePolicyRuleLocalDataLocalDatas[] | cdktf.IResolvable;
}
export declare function googleDnsResponsePolicyRuleLocalDataToTerraform(struct?: GoogleDnsResponsePolicyRuleLocalDataOutputReference | GoogleDnsResponsePolicyRuleLocalData): any;
export declare class GoogleDnsResponsePolicyRuleLocalDataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDnsResponsePolicyRuleLocalData | undefined;
    set internalValue(value: GoogleDnsResponsePolicyRuleLocalData | undefined);
    private _localDatas?;
    get localDatas(): GoogleDnsResponsePolicyRuleLocalDataLocalDatas[] | cdktf.IResolvable;
    set localDatas(value: GoogleDnsResponsePolicyRuleLocalDataLocalDatas[] | cdktf.IResolvable);
    get localDatasInput(): cdktf.IResolvable | GoogleDnsResponsePolicyRuleLocalDataLocalDatas[] | undefined;
}
export interface GoogleDnsResponsePolicyRuleTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy_rule#create GoogleDnsResponsePolicyRule#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy_rule#delete GoogleDnsResponsePolicyRule#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy_rule#update GoogleDnsResponsePolicyRule#update}
    */
    readonly update?: string;
}
export declare function googleDnsResponsePolicyRuleTimeoutsToTerraform(struct?: GoogleDnsResponsePolicyRuleTimeoutsOutputReference | GoogleDnsResponsePolicyRuleTimeouts | cdktf.IResolvable): any;
export declare class GoogleDnsResponsePolicyRuleTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDnsResponsePolicyRuleTimeouts | undefined;
    set internalValue(value: GoogleDnsResponsePolicyRuleTimeouts | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy_rule google_dns_response_policy_rule}
*/
export declare class GoogleDnsResponsePolicyRule extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_dns_response_policy_rule";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy_rule google_dns_response_policy_rule} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleDnsResponsePolicyRuleConfig
    */
    constructor(scope: Construct, id: string, config: GoogleDnsResponsePolicyRuleConfig);
    private _dnsName?;
    get dnsName(): string;
    set dnsName(value: string);
    get dnsNameInput(): string | undefined;
    get id(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _responsePolicy?;
    get responsePolicy(): string;
    set responsePolicy(value: string);
    get responsePolicyInput(): string | undefined;
    private _ruleName?;
    get ruleName(): string;
    set ruleName(value: string);
    get ruleNameInput(): string | undefined;
    private _localData;
    get localData(): GoogleDnsResponsePolicyRuleLocalDataOutputReference;
    putLocalData(value: GoogleDnsResponsePolicyRuleLocalData): void;
    resetLocalData(): void;
    get localDataInput(): GoogleDnsResponsePolicyRuleLocalData | undefined;
    private _timeouts;
    get timeouts(): GoogleDnsResponsePolicyRuleTimeoutsOutputReference;
    putTimeouts(value: GoogleDnsResponsePolicyRuleTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): GoogleDnsResponsePolicyRuleTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
//# sourceMappingURL=google-dns-response-policy-rule.d.ts.map