import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleDnsResponsePolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * The description of the response policy, such as 'My new response policy'.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy#description GoogleDnsResponsePolicy#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy#project GoogleDnsResponsePolicy#project}
    */
    readonly project?: string;
    /**
    * The user assigned name for this Response Policy, such as 'myresponsepolicy'.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy#response_policy_name GoogleDnsResponsePolicy#response_policy_name}
    */
    readonly responsePolicyName: string;
    /**
    * networks block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy#networks GoogleDnsResponsePolicy#networks}
    */
    readonly networks?: GoogleDnsResponsePolicyNetworks[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy#timeouts GoogleDnsResponsePolicy#timeouts}
    */
    readonly timeouts?: GoogleDnsResponsePolicyTimeouts;
}
export interface GoogleDnsResponsePolicyNetworks {
    /**
    * The fully qualified URL of the VPC network to bind to.
  This should be formatted like
  'https://www.googleapis.com/compute/v1/projects/{project}/global/networks/{network}'
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy#network_url GoogleDnsResponsePolicy#network_url}
    */
    readonly networkUrl: string;
}
export declare function googleDnsResponsePolicyNetworksToTerraform(struct?: GoogleDnsResponsePolicyNetworks | cdktf.IResolvable): any;
export interface GoogleDnsResponsePolicyTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy#create GoogleDnsResponsePolicy#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy#delete GoogleDnsResponsePolicy#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy#update GoogleDnsResponsePolicy#update}
    */
    readonly update?: string;
}
export declare function googleDnsResponsePolicyTimeoutsToTerraform(struct?: GoogleDnsResponsePolicyTimeoutsOutputReference | GoogleDnsResponsePolicyTimeouts | cdktf.IResolvable): any;
export declare class GoogleDnsResponsePolicyTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDnsResponsePolicyTimeouts | undefined;
    set internalValue(value: GoogleDnsResponsePolicyTimeouts | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy google_dns_response_policy}
*/
export declare class GoogleDnsResponsePolicy extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_dns_response_policy";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_response_policy google_dns_response_policy} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleDnsResponsePolicyConfig
    */
    constructor(scope: Construct, id: string, config: GoogleDnsResponsePolicyConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    get id(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _responsePolicyName?;
    get responsePolicyName(): string;
    set responsePolicyName(value: string);
    get responsePolicyNameInput(): string | undefined;
    private _networks?;
    get networks(): GoogleDnsResponsePolicyNetworks[] | cdktf.IResolvable;
    set networks(value: GoogleDnsResponsePolicyNetworks[] | cdktf.IResolvable);
    resetNetworks(): void;
    get networksInput(): cdktf.IResolvable | GoogleDnsResponsePolicyNetworks[] | undefined;
    private _timeouts;
    get timeouts(): GoogleDnsResponsePolicyTimeoutsOutputReference;
    putTimeouts(value: GoogleDnsResponsePolicyTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): GoogleDnsResponsePolicyTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
//# sourceMappingURL=google-dns-response-policy.d.ts.map