import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleFolderAccessApprovalSettingsConfig extends cdktf.TerraformMetaArguments {
    /**
    * The asymmetric crypto key version to use for signing approval requests.
  Empty active_key_version indicates that a Google-managed key should be used for signing.
  This property will be ignored if set by an ancestor of the resource, and new non-empty values may not be set.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_folder_access_approval_settings#active_key_version GoogleFolderAccessApprovalSettings#active_key_version}
    */
    readonly activeKeyVersion?: string;
    /**
    * ID of the folder of the access approval settings.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_folder_access_approval_settings#folder_id GoogleFolderAccessApprovalSettings#folder_id}
    */
    readonly folderId: string;
    /**
    * A list of email addresses to which notifications relating to approval requests should be sent.
  Notifications relating to a resource will be sent to all emails in the settings of ancestor
  resources of that resource. A maximum of 50 email addresses are allowed.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_folder_access_approval_settings#notification_emails GoogleFolderAccessApprovalSettings#notification_emails}
    */
    readonly notificationEmails?: string[];
    /**
    * enrolled_services block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_folder_access_approval_settings#enrolled_services GoogleFolderAccessApprovalSettings#enrolled_services}
    */
    readonly enrolledServices: GoogleFolderAccessApprovalSettingsEnrolledServices[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_folder_access_approval_settings#timeouts GoogleFolderAccessApprovalSettings#timeouts}
    */
    readonly timeouts?: GoogleFolderAccessApprovalSettingsTimeouts;
}
export interface GoogleFolderAccessApprovalSettingsEnrolledServices {
    /**
    * The product for which Access Approval will be enrolled. Allowed values are listed (case-sensitive):
    * all
    * App Engine
    * BigQuery
    * Cloud Bigtable
    * Cloud Key Management Service
    * Compute Engine
    * Cloud Dataflow
    * Cloud Identity and Access Management
    * Cloud Pub/Sub
    * Cloud Storage
    * Persistent Disk
  
  Note: These values are supported as input, but considered a legacy format:
    * all
    * appengine.googleapis.com
    * bigquery.googleapis.com
    * bigtable.googleapis.com
    * cloudkms.googleapis.com
    * compute.googleapis.com
    * dataflow.googleapis.com
    * iam.googleapis.com
    * pubsub.googleapis.com
    * storage.googleapis.com
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_folder_access_approval_settings#cloud_product GoogleFolderAccessApprovalSettings#cloud_product}
    */
    readonly cloudProduct: string;
    /**
    * The enrollment level of the service. Default value: "BLOCK_ALL" Possible values: ["BLOCK_ALL"]
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_folder_access_approval_settings#enrollment_level GoogleFolderAccessApprovalSettings#enrollment_level}
    */
    readonly enrollmentLevel?: string;
}
export declare function googleFolderAccessApprovalSettingsEnrolledServicesToTerraform(struct?: GoogleFolderAccessApprovalSettingsEnrolledServices | cdktf.IResolvable): any;
export interface GoogleFolderAccessApprovalSettingsTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_folder_access_approval_settings#create GoogleFolderAccessApprovalSettings#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_folder_access_approval_settings#delete GoogleFolderAccessApprovalSettings#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_folder_access_approval_settings#update GoogleFolderAccessApprovalSettings#update}
    */
    readonly update?: string;
}
export declare function googleFolderAccessApprovalSettingsTimeoutsToTerraform(struct?: GoogleFolderAccessApprovalSettingsTimeoutsOutputReference | GoogleFolderAccessApprovalSettingsTimeouts | cdktf.IResolvable): any;
export declare class GoogleFolderAccessApprovalSettingsTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleFolderAccessApprovalSettingsTimeouts | undefined;
    set internalValue(value: GoogleFolderAccessApprovalSettingsTimeouts | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_folder_access_approval_settings google_folder_access_approval_settings}
*/
export declare class GoogleFolderAccessApprovalSettings extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_folder_access_approval_settings";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_folder_access_approval_settings google_folder_access_approval_settings} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleFolderAccessApprovalSettingsConfig
    */
    constructor(scope: Construct, id: string, config: GoogleFolderAccessApprovalSettingsConfig);
    private _activeKeyVersion?;
    get activeKeyVersion(): string;
    set activeKeyVersion(value: string);
    resetActiveKeyVersion(): void;
    get activeKeyVersionInput(): string | undefined;
    get ancestorHasActiveKeyVersion(): cdktf.IResolvable;
    get enrolledAncestor(): cdktf.IResolvable;
    private _folderId?;
    get folderId(): string;
    set folderId(value: string);
    get folderIdInput(): string | undefined;
    get id(): string;
    get invalidKeyVersion(): cdktf.IResolvable;
    get name(): string;
    private _notificationEmails?;
    get notificationEmails(): string[];
    set notificationEmails(value: string[]);
    resetNotificationEmails(): void;
    get notificationEmailsInput(): string[] | undefined;
    private _enrolledServices?;
    get enrolledServices(): GoogleFolderAccessApprovalSettingsEnrolledServices[] | cdktf.IResolvable;
    set enrolledServices(value: GoogleFolderAccessApprovalSettingsEnrolledServices[] | cdktf.IResolvable);
    get enrolledServicesInput(): cdktf.IResolvable | GoogleFolderAccessApprovalSettingsEnrolledServices[] | undefined;
    private _timeouts;
    get timeouts(): GoogleFolderAccessApprovalSettingsTimeoutsOutputReference;
    putTimeouts(value: GoogleFolderAccessApprovalSettingsTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): GoogleFolderAccessApprovalSettingsTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
//# sourceMappingURL=google-folder-access-approval-settings.d.ts.map