import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleLoggingOrganizationSinkConfig extends cdktf.TerraformMetaArguments {
    /**
    * A description of this sink. The maximum length of the description is 8000 characters.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_logging_organization_sink#description GoogleLoggingOrganizationSink#description}
    */
    readonly description?: string;
    /**
    * The destination of the sink (or, in other words, where logs are written to). Can be a Cloud Storage bucket, a PubSub topic, or a BigQuery dataset. Examples: "storage.googleapis.com/[GCS_BUCKET]" "bigquery.googleapis.com/projects/[PROJECT_ID]/datasets/[DATASET]" "pubsub.googleapis.com/projects/[PROJECT_ID]/topics/[TOPIC_ID]" The writer associated with the sink must have access to write to the above resource.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_logging_organization_sink#destination GoogleLoggingOrganizationSink#destination}
    */
    readonly destination: string;
    /**
    * If set to True, then this sink is disabled and it does not export any log entries.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_logging_organization_sink#disabled GoogleLoggingOrganizationSink#disabled}
    */
    readonly disabled?: boolean | cdktf.IResolvable;
    /**
    * The filter to apply when exporting logs. Only log entries that match the filter are exported.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_logging_organization_sink#filter GoogleLoggingOrganizationSink#filter}
    */
    readonly filter?: string;
    /**
    * Whether or not to include children organizations in the sink export. If true, logs associated with child projects are also exported; otherwise only logs relating to the provided organization are included.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_logging_organization_sink#include_children GoogleLoggingOrganizationSink#include_children}
    */
    readonly includeChildren?: boolean | cdktf.IResolvable;
    /**
    * The name of the logging sink.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_logging_organization_sink#name GoogleLoggingOrganizationSink#name}
    */
    readonly name: string;
    /**
    * The numeric ID of the organization to be exported to the sink.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_logging_organization_sink#org_id GoogleLoggingOrganizationSink#org_id}
    */
    readonly orgId: string;
    /**
    * bigquery_options block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_logging_organization_sink#bigquery_options GoogleLoggingOrganizationSink#bigquery_options}
    */
    readonly bigqueryOptions?: GoogleLoggingOrganizationSinkBigqueryOptions;
    /**
    * exclusions block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_logging_organization_sink#exclusions GoogleLoggingOrganizationSink#exclusions}
    */
    readonly exclusions?: GoogleLoggingOrganizationSinkExclusions[] | cdktf.IResolvable;
}
export interface GoogleLoggingOrganizationSinkBigqueryOptions {
    /**
    * Whether to use BigQuery's partition tables. By default, Logging creates dated tables based on the log entries' timestamps, e.g. syslog_20170523. With partitioned tables the date suffix is no longer present and special query syntax has to be used instead. In both cases, tables are sharded based on UTC timezone.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_logging_organization_sink#use_partitioned_tables GoogleLoggingOrganizationSink#use_partitioned_tables}
    */
    readonly usePartitionedTables: boolean | cdktf.IResolvable;
}
export declare function googleLoggingOrganizationSinkBigqueryOptionsToTerraform(struct?: GoogleLoggingOrganizationSinkBigqueryOptionsOutputReference | GoogleLoggingOrganizationSinkBigqueryOptions): any;
export declare class GoogleLoggingOrganizationSinkBigqueryOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleLoggingOrganizationSinkBigqueryOptions | undefined;
    set internalValue(value: GoogleLoggingOrganizationSinkBigqueryOptions | undefined);
    private _usePartitionedTables?;
    get usePartitionedTables(): boolean | cdktf.IResolvable;
    set usePartitionedTables(value: boolean | cdktf.IResolvable);
    get usePartitionedTablesInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GoogleLoggingOrganizationSinkExclusions {
    /**
    * A description of this exclusion.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_logging_organization_sink#description GoogleLoggingOrganizationSink#description}
    */
    readonly description?: string;
    /**
    * If set to True, then this exclusion is disabled and it does not exclude any log entries
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_logging_organization_sink#disabled GoogleLoggingOrganizationSink#disabled}
    */
    readonly disabled?: boolean | cdktf.IResolvable;
    /**
    * An advanced logs filter that matches the log entries to be excluded. By using the sample function, you can exclude less than 100% of the matching log entries
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_logging_organization_sink#filter GoogleLoggingOrganizationSink#filter}
    */
    readonly filter: string;
    /**
    * A client-assigned identifier, such as "load-balancer-exclusion". Identifiers are limited to 100 characters and can include only letters, digits, underscores, hyphens, and periods. First character has to be alphanumeric.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_logging_organization_sink#name GoogleLoggingOrganizationSink#name}
    */
    readonly name: string;
}
export declare function googleLoggingOrganizationSinkExclusionsToTerraform(struct?: GoogleLoggingOrganizationSinkExclusions | cdktf.IResolvable): any;
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_logging_organization_sink google_logging_organization_sink}
*/
export declare class GoogleLoggingOrganizationSink extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_logging_organization_sink";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_logging_organization_sink google_logging_organization_sink} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleLoggingOrganizationSinkConfig
    */
    constructor(scope: Construct, id: string, config: GoogleLoggingOrganizationSinkConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _destination?;
    get destination(): string;
    set destination(value: string);
    get destinationInput(): string | undefined;
    private _disabled?;
    get disabled(): boolean | cdktf.IResolvable;
    set disabled(value: boolean | cdktf.IResolvable);
    resetDisabled(): void;
    get disabledInput(): boolean | cdktf.IResolvable | undefined;
    private _filter?;
    get filter(): string;
    set filter(value: string);
    resetFilter(): void;
    get filterInput(): string | undefined;
    get id(): string;
    private _includeChildren?;
    get includeChildren(): boolean | cdktf.IResolvable;
    set includeChildren(value: boolean | cdktf.IResolvable);
    resetIncludeChildren(): void;
    get includeChildrenInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _orgId?;
    get orgId(): string;
    set orgId(value: string);
    get orgIdInput(): string | undefined;
    get writerIdentity(): string;
    private _bigqueryOptions;
    get bigqueryOptions(): GoogleLoggingOrganizationSinkBigqueryOptionsOutputReference;
    putBigqueryOptions(value: GoogleLoggingOrganizationSinkBigqueryOptions): void;
    resetBigqueryOptions(): void;
    get bigqueryOptionsInput(): GoogleLoggingOrganizationSinkBigqueryOptions | undefined;
    private _exclusions?;
    get exclusions(): GoogleLoggingOrganizationSinkExclusions[] | cdktf.IResolvable;
    set exclusions(value: GoogleLoggingOrganizationSinkExclusions[] | cdktf.IResolvable);
    resetExclusions(): void;
    get exclusionsInput(): cdktf.IResolvable | GoogleLoggingOrganizationSinkExclusions[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
//# sourceMappingURL=google-logging-organization-sink.d.ts.map