import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleSecretManagerSecretConfig extends cdktf.TerraformMetaArguments {
    /**
    * Timestamp in UTC when the Secret is scheduled to expire. This is always provided on output, regardless of what was sent on input.
  A timestamp in RFC3339 UTC "Zulu" format, with nanosecond resolution and up to nine fractional digits. Examples: "2014-10-02T15:01:23Z" and "2014-10-02T15:01:23.045123456Z".
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret#expire_time GoogleSecretManagerSecret#expire_time}
    */
    readonly expireTime?: string;
    /**
    * The labels assigned to this Secret.
  
  Label keys must be between 1 and 63 characters long, have a UTF-8 encoding of maximum 128 bytes,
  and must conform to the following PCRE regular expression: [\p{Ll}\p{Lo}][\p{Ll}\p{Lo}\p{N}_-]{0,62}
  
  Label values must be between 0 and 63 characters long, have a UTF-8 encoding of maximum 128 bytes,
  and must conform to the following PCRE regular expression: [\p{Ll}\p{Lo}\p{N}_-]{0,63}
  
  No more than 64 labels can be assigned to a given resource.
  
  An object containing a list of "key": value pairs. Example:
  { "name": "wrench", "mass": "1.3kg", "count": "3" }.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret#labels GoogleSecretManagerSecret#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret#project GoogleSecretManagerSecret#project}
    */
    readonly project?: string;
    /**
    * This must be unique within the project.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret#secret_id GoogleSecretManagerSecret#secret_id}
    */
    readonly secretId: string;
    /**
    * The TTL for the Secret.
  A duration in seconds with up to nine fractional digits, terminated by 's'. Example: "3.5s".
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret#ttl GoogleSecretManagerSecret#ttl}
    */
    readonly ttl?: string;
    /**
    * replication block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret#replication GoogleSecretManagerSecret#replication}
    */
    readonly replication: GoogleSecretManagerSecretReplication;
    /**
    * rotation block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret#rotation GoogleSecretManagerSecret#rotation}
    */
    readonly rotation?: GoogleSecretManagerSecretRotation;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret#timeouts GoogleSecretManagerSecret#timeouts}
    */
    readonly timeouts?: GoogleSecretManagerSecretTimeouts;
    /**
    * topics block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret#topics GoogleSecretManagerSecret#topics}
    */
    readonly topics?: GoogleSecretManagerSecretTopics[] | cdktf.IResolvable;
}
export interface GoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryption {
    /**
    * Describes the Cloud KMS encryption key that will be used to protect destination secret.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret#kms_key_name GoogleSecretManagerSecret#kms_key_name}
    */
    readonly kmsKeyName: string;
}
export declare function googleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryptionToTerraform(struct?: GoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryptionOutputReference | GoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryption): any;
export declare class GoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryptionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryption | undefined;
    set internalValue(value: GoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryption | undefined);
    private _kmsKeyName?;
    get kmsKeyName(): string;
    set kmsKeyName(value: string);
    get kmsKeyNameInput(): string | undefined;
}
export interface GoogleSecretManagerSecretReplicationUserManagedReplicas {
    /**
    * The canonical IDs of the location to replicate data. For example: "us-east1".
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret#location GoogleSecretManagerSecret#location}
    */
    readonly location: string;
    /**
    * customer_managed_encryption block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret#customer_managed_encryption GoogleSecretManagerSecret#customer_managed_encryption}
    */
    readonly customerManagedEncryption?: GoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryption;
}
export declare function googleSecretManagerSecretReplicationUserManagedReplicasToTerraform(struct?: GoogleSecretManagerSecretReplicationUserManagedReplicas | cdktf.IResolvable): any;
export interface GoogleSecretManagerSecretReplicationUserManaged {
    /**
    * replicas block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret#replicas GoogleSecretManagerSecret#replicas}
    */
    readonly replicas: GoogleSecretManagerSecretReplicationUserManagedReplicas[] | cdktf.IResolvable;
}
export declare function googleSecretManagerSecretReplicationUserManagedToTerraform(struct?: GoogleSecretManagerSecretReplicationUserManagedOutputReference | GoogleSecretManagerSecretReplicationUserManaged): any;
export declare class GoogleSecretManagerSecretReplicationUserManagedOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleSecretManagerSecretReplicationUserManaged | undefined;
    set internalValue(value: GoogleSecretManagerSecretReplicationUserManaged | undefined);
    private _replicas?;
    get replicas(): GoogleSecretManagerSecretReplicationUserManagedReplicas[] | cdktf.IResolvable;
    set replicas(value: GoogleSecretManagerSecretReplicationUserManagedReplicas[] | cdktf.IResolvable);
    get replicasInput(): cdktf.IResolvable | GoogleSecretManagerSecretReplicationUserManagedReplicas[] | undefined;
}
export interface GoogleSecretManagerSecretReplication {
    /**
    * The Secret will automatically be replicated without any restrictions.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret#automatic GoogleSecretManagerSecret#automatic}
    */
    readonly automatic?: boolean | cdktf.IResolvable;
    /**
    * user_managed block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret#user_managed GoogleSecretManagerSecret#user_managed}
    */
    readonly userManaged?: GoogleSecretManagerSecretReplicationUserManaged;
}
export declare function googleSecretManagerSecretReplicationToTerraform(struct?: GoogleSecretManagerSecretReplicationOutputReference | GoogleSecretManagerSecretReplication): any;
export declare class GoogleSecretManagerSecretReplicationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleSecretManagerSecretReplication | undefined;
    set internalValue(value: GoogleSecretManagerSecretReplication | undefined);
    private _automatic?;
    get automatic(): boolean | cdktf.IResolvable;
    set automatic(value: boolean | cdktf.IResolvable);
    resetAutomatic(): void;
    get automaticInput(): boolean | cdktf.IResolvable | undefined;
    private _userManaged;
    get userManaged(): GoogleSecretManagerSecretReplicationUserManagedOutputReference;
    putUserManaged(value: GoogleSecretManagerSecretReplicationUserManaged): void;
    resetUserManaged(): void;
    get userManagedInput(): GoogleSecretManagerSecretReplicationUserManaged | undefined;
}
export interface GoogleSecretManagerSecretRotation {
    /**
    * Timestamp in UTC at which the Secret is scheduled to rotate.
  A timestamp in RFC3339 UTC "Zulu" format, with nanosecond resolution and up to nine fractional digits. Examples: "2014-10-02T15:01:23Z" and "2014-10-02T15:01:23.045123456Z".
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret#next_rotation_time GoogleSecretManagerSecret#next_rotation_time}
    */
    readonly nextRotationTime?: string;
    /**
    * The Duration between rotation notifications. Must be in seconds and at least 3600s (1h) and at most 3153600000s (100 years).
  If rotationPeriod is set, 'next_rotation_time' must be set. 'next_rotation_time' will be advanced by this period when the service automatically sends rotation notifications.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret#rotation_period GoogleSecretManagerSecret#rotation_period}
    */
    readonly rotationPeriod?: string;
}
export declare function googleSecretManagerSecretRotationToTerraform(struct?: GoogleSecretManagerSecretRotationOutputReference | GoogleSecretManagerSecretRotation): any;
export declare class GoogleSecretManagerSecretRotationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleSecretManagerSecretRotation | undefined;
    set internalValue(value: GoogleSecretManagerSecretRotation | undefined);
    private _nextRotationTime?;
    get nextRotationTime(): string;
    set nextRotationTime(value: string);
    resetNextRotationTime(): void;
    get nextRotationTimeInput(): string | undefined;
    private _rotationPeriod?;
    get rotationPeriod(): string;
    set rotationPeriod(value: string);
    resetRotationPeriod(): void;
    get rotationPeriodInput(): string | undefined;
}
export interface GoogleSecretManagerSecretTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret#create GoogleSecretManagerSecret#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret#delete GoogleSecretManagerSecret#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret#update GoogleSecretManagerSecret#update}
    */
    readonly update?: string;
}
export declare function googleSecretManagerSecretTimeoutsToTerraform(struct?: GoogleSecretManagerSecretTimeoutsOutputReference | GoogleSecretManagerSecretTimeouts | cdktf.IResolvable): any;
export declare class GoogleSecretManagerSecretTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleSecretManagerSecretTimeouts | undefined;
    set internalValue(value: GoogleSecretManagerSecretTimeouts | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
export interface GoogleSecretManagerSecretTopics {
    /**
    * The resource name of the Pub/Sub topic that will be published to, in the following format: projects/*\/topics/*.
  For publication to succeed, the Secret Manager Service Agent service account must have pubsub.publisher permissions on the topic.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret#name GoogleSecretManagerSecret#name}
    */
    readonly name: string;
}
export declare function googleSecretManagerSecretTopicsToTerraform(struct?: GoogleSecretManagerSecretTopics | cdktf.IResolvable): any;
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret google_secret_manager_secret}
*/
export declare class GoogleSecretManagerSecret extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_secret_manager_secret";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_secret_manager_secret google_secret_manager_secret} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleSecretManagerSecretConfig
    */
    constructor(scope: Construct, id: string, config: GoogleSecretManagerSecretConfig);
    get createTime(): string;
    private _expireTime?;
    get expireTime(): string;
    set expireTime(value: string);
    resetExpireTime(): void;
    get expireTimeInput(): string | undefined;
    get id(): string;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _secretId?;
    get secretId(): string;
    set secretId(value: string);
    get secretIdInput(): string | undefined;
    private _ttl?;
    get ttl(): string;
    set ttl(value: string);
    resetTtl(): void;
    get ttlInput(): string | undefined;
    private _replication;
    get replication(): GoogleSecretManagerSecretReplicationOutputReference;
    putReplication(value: GoogleSecretManagerSecretReplication): void;
    get replicationInput(): GoogleSecretManagerSecretReplication | undefined;
    private _rotation;
    get rotation(): GoogleSecretManagerSecretRotationOutputReference;
    putRotation(value: GoogleSecretManagerSecretRotation): void;
    resetRotation(): void;
    get rotationInput(): GoogleSecretManagerSecretRotation | undefined;
    private _timeouts;
    get timeouts(): GoogleSecretManagerSecretTimeoutsOutputReference;
    putTimeouts(value: GoogleSecretManagerSecretTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): GoogleSecretManagerSecretTimeouts | undefined;
    private _topics?;
    get topics(): GoogleSecretManagerSecretTopics[] | cdktf.IResolvable;
    set topics(value: GoogleSecretManagerSecretTopics[] | cdktf.IResolvable);
    resetTopics(): void;
    get topicsInput(): cdktf.IResolvable | GoogleSecretManagerSecretTopics[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
//# sourceMappingURL=google-secret-manager-secret.d.ts.map