import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleServiceNetworkingPeeredDnsDomainConfig extends cdktf.TerraformMetaArguments {
    /**
    * The DNS domain name suffix of the peered DNS domain.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_service_networking_peered_dns_domain#dns_suffix GoogleServiceNetworkingPeeredDnsDomain#dns_suffix}
    */
    readonly dnsSuffix: string;
    /**
    * Name of the peered DNS domain.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_service_networking_peered_dns_domain#name GoogleServiceNetworkingPeeredDnsDomain#name}
    */
    readonly name: string;
    /**
    * Network in the consumer project to peer with.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_service_networking_peered_dns_domain#network GoogleServiceNetworkingPeeredDnsDomain#network}
    */
    readonly network: string;
    /**
    * The ID of the project that the service account will be created in. Defaults to the provider project configuration.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_service_networking_peered_dns_domain#project GoogleServiceNetworkingPeeredDnsDomain#project}
    */
    readonly project?: string;
    /**
    * The name of the service to create a peered DNS domain for, e.g. servicenetworking.googleapis.com
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_service_networking_peered_dns_domain#service GoogleServiceNetworkingPeeredDnsDomain#service}
    */
    readonly service?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_service_networking_peered_dns_domain#timeouts GoogleServiceNetworkingPeeredDnsDomain#timeouts}
    */
    readonly timeouts?: GoogleServiceNetworkingPeeredDnsDomainTimeouts;
}
export interface GoogleServiceNetworkingPeeredDnsDomainTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_service_networking_peered_dns_domain#create GoogleServiceNetworkingPeeredDnsDomain#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_service_networking_peered_dns_domain#delete GoogleServiceNetworkingPeeredDnsDomain#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_service_networking_peered_dns_domain#read GoogleServiceNetworkingPeeredDnsDomain#read}
    */
    readonly read?: string;
}
export declare function googleServiceNetworkingPeeredDnsDomainTimeoutsToTerraform(struct?: GoogleServiceNetworkingPeeredDnsDomainTimeoutsOutputReference | GoogleServiceNetworkingPeeredDnsDomainTimeouts | cdktf.IResolvable): any;
export declare class GoogleServiceNetworkingPeeredDnsDomainTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleServiceNetworkingPeeredDnsDomainTimeouts | undefined;
    set internalValue(value: GoogleServiceNetworkingPeeredDnsDomainTimeouts | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_service_networking_peered_dns_domain google_service_networking_peered_dns_domain}
*/
export declare class GoogleServiceNetworkingPeeredDnsDomain extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_service_networking_peered_dns_domain";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_service_networking_peered_dns_domain google_service_networking_peered_dns_domain} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleServiceNetworkingPeeredDnsDomainConfig
    */
    constructor(scope: Construct, id: string, config: GoogleServiceNetworkingPeeredDnsDomainConfig);
    private _dnsSuffix?;
    get dnsSuffix(): string;
    set dnsSuffix(value: string);
    get dnsSuffixInput(): string | undefined;
    get id(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _network?;
    get network(): string;
    set network(value: string);
    get networkInput(): string | undefined;
    get parent(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _service?;
    get service(): string;
    set service(value: string);
    resetService(): void;
    get serviceInput(): string | undefined;
    private _timeouts;
    get timeouts(): GoogleServiceNetworkingPeeredDnsDomainTimeoutsOutputReference;
    putTimeouts(value: GoogleServiceNetworkingPeeredDnsDomainTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): GoogleServiceNetworkingPeeredDnsDomainTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
//# sourceMappingURL=google-service-networking-peered-dns-domain.d.ts.map