import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleSourcerepoRepositoryConfig extends cdktf.TerraformMetaArguments {
    /**
    * Resource name of the repository, of the form '{{repo}}'.
  The repo name may contain slashes. eg, 'name/with/slash'
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_sourcerepo_repository#name GoogleSourcerepoRepository#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_sourcerepo_repository#project GoogleSourcerepoRepository#project}
    */
    readonly project?: string;
    /**
    * pubsub_configs block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_sourcerepo_repository#pubsub_configs GoogleSourcerepoRepository#pubsub_configs}
    */
    readonly pubsubConfigs?: GoogleSourcerepoRepositoryPubsubConfigs[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_sourcerepo_repository#timeouts GoogleSourcerepoRepository#timeouts}
    */
    readonly timeouts?: GoogleSourcerepoRepositoryTimeouts;
}
export interface GoogleSourcerepoRepositoryPubsubConfigs {
    /**
    * The format of the Cloud Pub/Sub messages.
  - PROTOBUF: The message payload is a serialized protocol buffer of SourceRepoEvent.
  - JSON: The message payload is a JSON string of SourceRepoEvent. Possible values: ["PROTOBUF", "JSON"]
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_sourcerepo_repository#message_format GoogleSourcerepoRepository#message_format}
    */
    readonly messageFormat: string;
    /**
    * Email address of the service account used for publishing Cloud Pub/Sub messages.
  This service account needs to be in the same project as the PubsubConfig. When added,
  the caller needs to have iam.serviceAccounts.actAs permission on this service account.
  If unspecified, it defaults to the compute engine default service account.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_sourcerepo_repository#service_account_email GoogleSourcerepoRepository#service_account_email}
    */
    readonly serviceAccountEmail?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_sourcerepo_repository#topic GoogleSourcerepoRepository#topic}
    */
    readonly topic: string;
}
export declare function googleSourcerepoRepositoryPubsubConfigsToTerraform(struct?: GoogleSourcerepoRepositoryPubsubConfigs | cdktf.IResolvable): any;
export interface GoogleSourcerepoRepositoryTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_sourcerepo_repository#create GoogleSourcerepoRepository#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_sourcerepo_repository#delete GoogleSourcerepoRepository#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_sourcerepo_repository#update GoogleSourcerepoRepository#update}
    */
    readonly update?: string;
}
export declare function googleSourcerepoRepositoryTimeoutsToTerraform(struct?: GoogleSourcerepoRepositoryTimeoutsOutputReference | GoogleSourcerepoRepositoryTimeouts | cdktf.IResolvable): any;
export declare class GoogleSourcerepoRepositoryTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleSourcerepoRepositoryTimeouts | undefined;
    set internalValue(value: GoogleSourcerepoRepositoryTimeouts | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_sourcerepo_repository google_sourcerepo_repository}
*/
export declare class GoogleSourcerepoRepository extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_sourcerepo_repository";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_sourcerepo_repository google_sourcerepo_repository} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleSourcerepoRepositoryConfig
    */
    constructor(scope: Construct, id: string, config: GoogleSourcerepoRepositoryConfig);
    get id(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get size(): number;
    get url(): string;
    private _pubsubConfigs?;
    get pubsubConfigs(): GoogleSourcerepoRepositoryPubsubConfigs[] | cdktf.IResolvable;
    set pubsubConfigs(value: GoogleSourcerepoRepositoryPubsubConfigs[] | cdktf.IResolvable);
    resetPubsubConfigs(): void;
    get pubsubConfigsInput(): cdktf.IResolvable | GoogleSourcerepoRepositoryPubsubConfigs[] | undefined;
    private _timeouts;
    get timeouts(): GoogleSourcerepoRepositoryTimeoutsOutputReference;
    putTimeouts(value: GoogleSourcerepoRepositoryTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): GoogleSourcerepoRepositoryTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
//# sourceMappingURL=google-sourcerepo-repository.d.ts.map